Package: StabMap
Type: Package
Title: Stabilised mosaic single cell data integration using unshared
        features
Version: 1.6.0
Authors@R: c(
    person("Shila", "Ghazanfar", , "shazanfar@gmail.com", role = c("aut", "cre", "ctb")),
    person("Aiden", "Jin", role = "ctb"),
    person("Nicholas", "Robertson", , "nicholas.robertson@sydney.edu.au", role = "ctb")
  )
Description: StabMap performs single cell mosaic data integration by first 
    building a mosaic data topology, and for each reference dataset, traverses 
    the topology to project and predict data onto a common embedding. Mosaic
    data should be provided in a list format, with all relevant features 
    included in the data matrices within each list object. The output of
    stabMap is a joint low-dimensional embedding taking into account all 
    available relevant features. Expression imputation can also be performed
    using the StabMap embedding and any of the original data matrices for 
    given reference and query cell lists.
License: GPL-2
Encoding: UTF-8
URL: https://sydneybiox.github.io/StabMap,
        https://sydneybiox.github.io/StabMap/
BugReports: https://github.com/sydneybiox/StabMap/issues
biocViews: SingleCell, DimensionReduction, Software
Depends: R (>= 4.4.0),
Imports: igraph, slam, BiocNeighbors, Matrix, MASS, abind,
        SummarizedExperiment, methods, MatrixGenerics, BiocGenerics,
        BiocSingular, BiocParallel
Suggests: scran, scater, knitr, UpSetR, gridExtra,
        SingleCellMultiModal, BiocStyle, magrittr, testthat (>= 3.0.0),
        purrr, sparseMatrixStats
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/StabMap
git_branch: RELEASE_3_23
git_last_commit: 2c98354
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:06:02 UTC; biocbuild
Author: Shila Ghazanfar [aut, cre, ctb],
  Aiden Jin [ctb],
  Nicholas Robertson [ctb]
Maintainer: Shila Ghazanfar <shazanfar@gmail.com>
